/**********************************************************************
*                                                                     *
*  posix2.cc: Rule File To Check Functions Both In POSIX.1 and        *
*             ANSI C                                                  *
*                                                                     *
*  Version 2.0                                                        *
*                                                                     *
*  By Y. Jenny Luo                                                    *
*                                                                     *
*  PCYACC (R) is a software product of ABRAXAS SOFTWARE INC.          *
*  Copyright (C) 1986-1996 by ABRAXAS SOFTWARE INC.                   *
*                                                                     *
*  Reference: The POSIX.1 Standard: A Programmer's Guide              *
*             Author: Fred Zlotnick, Mindcraft, Inc.                  *
*             ISBN: 0-8053-9605-5                                     *
*                                                                     *
***********************************************************************
*  Warning Code:                                                      *
*	2001	Leading underscores are reserved by POSIX.            *
*       2002    <*.h> header file is not included.                    *
*	2003    The number of arguments is incorrect.                 *
*     	2004	argument with incorrect type.                         *
***********************************************************************
*  Note:                                                              *
*	This rule file does not check system dependent data types     *
*	due to the fact that CodeCheck will return the ultimate types *
*	defined in library when users use op_base_name function. For  *
*	this part type checking, please contact ABRAXAS for further   *
*       POSIX update rule file.                                       *  
**********************************************************************/

#include <check.cch>	/* standard CodeCheck header file for constants */

int posix_need;		/* 1 if _POSIX_SOURCE has not been defined */

/* system header files for both POSIX.1 and ANSI C */
int errno_include,  	/* 1 if header errno.h has been #included */
    limits_include,     /* 1 if header limits.h has been #included */
    setjmp_include,     /* 1 if header setjmp.h has been #included */
    signal_include;	/* 1 if header signal.h has been #included */

/* system header files for POSIX.1 Only */
int dirent_include,	 /* 1 if dirent.h has been #included */
    fcntl_include,	 /* 1 if fcntl.h has been #included */
    grp_include,	 /* 1 if grp.h has been #included */
    pwd_include,	 /* 1 if pwd.h has been #included */
    sys_stat_include,	 /* 1 if sys/stat.h has been #included */
    sys_times_include,	 /* 1 if sys/times.h has been #included */
    sys_types_include,	 /* 1 if sys/types_include.h has been #included */
    sys_utsname_include, /* 1 if sys/utsname.h has been #included */
    sys_wait_include,    /* 1 if sys/wait.h has been #included */
    tar_include,	 /* 1 if tar.h has been #included */
    termios_include,	 /* 1 if termios.h has been #included */
    unistd_include,      /* 1 if unistd.h has been #included */
    utime_include;       /* 1 if utime.h has been #included */

/* system header files for ANSI C Only */
int assert_include,      /* 1 if assert.h has been #included */
    ctype_include,       /* 1 if ctype.h has been #included */
    float_include,       /* 1 if float.h has been #included */
    flow_include,        /* 1 if flow.h has been #included */
    locale_include,      /* 1 if locale.h has been #included */
    math_include,        /* 1 if math.h has been #included */
    stdarg_include,      /* 1 if stdarg.h has been #included */
    stddef_include,      /* 1 if stddef.h has been #included */
    stdio_include,       /* 1 if stdio.h has been #included */
    stdlib_include,      /* 1 if stdlib.h has been #included */
    string_include,      /* 1 if string.h has been #included */
    time_include;        /* 1 if time.h has been #included */

if (mod_begin)
{
  posix_need = 1;
  //set_option('S', 1);	/* Make sure that project headers are checked, and
  //                      that system headers are not checked (option -S1)*/						 
}

if (pp_macro)
{
  if (prefix("_"))
  {
    if (strcmp(pp_name(), "_POSIX_SOURCE") == 0)
      posix_need = 0;
    else
      warn(2001, "%s: Leading underscores are reserved by POSIX.",
           dcl_name());
  }
}

if (dcl_underscore)
  warn(2001, "%s: Leading underscores are reserved by POSIX.",
       dcl_name());

if (header_name())	/* triggers whenever an #include is met. */
{
  if (posix_need)
  {
    warn(2000, "Precede all headers with #define _POSIX_SOURCE");
    posix_need = 0;	/* prevent multiple warning */
  }

  /* system headers for both POSIX.1 and ANSI C */
  if (strcmp(header_name(), "errno.h") == 0)
    errno_include = 1;
  else if (strcmp(header_name(), "limits.h") == 0)
    limits_include = 1;
  else if (strcmp(header_name(), "setjmp.h") == 0)
    setjmp_include = 1;
  else if (strcmp(header_name(), "signal.h") == 0)
    signal_include = 1;

  /* system headers for POSIX.1 Only */
  else if (strcmp(header_name(), "dirent.h") == 0)
    dirent_include = 1;
  else if (strcmp(header_name(), "fcntl.h") == 0)
    fcntl_include = 1;
  else if (strcmp(header_name(), "grp.h") == 0)
    grp_include = 1;
  else if (strcmp(header_name(), "pwd.h") == 0)
    pwd_include = 1;
  else if (strcmp(header_name(), "sys/stat.h") == 0)
    sys_stat_include = 1;
  else if (strcmp(header_name(), "sys/times.h") == 0)
    sys_times_include = 1;
  else if (strcmp(header_name(), "sys/types.h") == 0)
     sys_types_include = 1;
  else if (strcmp(header_name(), "sys/utsname.h") == 0)
    sys_utsname_include = 1;
   else if (strcmp(header_name(), "sys/wait.h") == 0)
    sys_wait_include = 1;
  else if (strcmp(header_name(), "tar.h") == 0)
    tar_include = 1;
  else if (strcmp(header_name(), "termios.h") == 0)
    termios_include = 1;
  else if (strcmp(header_name(), "unistd.h") == 0)
    unistd_include = 1;
  else if (strcmp(header_name(), "utime.h") == 0)
    utime_include = 1;

  /* system headers for ANSI C Only */
  else if (strcmp(header_name(), "assert.h") == 0)
    assert_include = 1;
  else if (strcmp(header_name(), "ctype.h") == 0)
    ctype_include = 1;
  else if (strcmp(header_name(), "float.h") == 0)
    float_include = 1;
  else if (strcmp(header_name(), "flow.h") == 0)
    flow_include = 1;
  else if (strcmp(header_name(), "locale.h") == 0)
    locale_include = 1;
  else if (strcmp(header_name(), "math.h") == 0)
    math_include = 1;
  else if (strcmp(header_name(), "stdarg.h") == 0)
    stdarg_include = 1;
  else if (strcmp(header_name(), "stddef.h") == 0)
    stddef_include = 1;
  else if (strcmp(header_name(), "stdio.h") == 0)
    stdio_include = 1;
  else if (strcmp(header_name(), "stdlib.h") == 0)
    stdlib_include = 1;
  else if (strcmp(header_name(), "string.h") == 0)
    string_include = 1;
  else if (strcmp(header_name(), "time.h") == 0)
    time_include = 1;
}

/* check the header files required for POSIX.1 function only */
if (op_call)
{
  if (strcmp(op_function(), "access")==0)
  {
    if (!unistd_include)	/* check header file */
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_base(2)!=CHAR_TYPE)	/* char type */	  
        warn(2004, "%s: argument with incorrect type.", op_function()); 
      else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  }  
  else if (strcmp(op_function(), "alarm") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=UINT_TYPE)	/* unsigned int type */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  }
  else if (strcmp(op_function(), "cfgetispeed") == 0)
  {
    if (!termios_include)
      warn(2002, "%s: termios.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=STRUCT_TYPE)	/* check argument's type:struct */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (strcmp(op_base_name(1), "termios") != 0)
        warn(2004, "%s: argument with incorrect type.", op_function()); 
      else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  }
  else if (strcmp(op_function(), "cfgetospeed") == 0)
  {
    if (!termios_include)
      warn(2002, "%s: termios.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=STRUCT_TYPE)	/* check argument's type:struct */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (strcmp(op_base_name(1), "termios") != 0)
        warn(2004, "%s: argument with incorrect type.", op_function()); 
      else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  }
  else if (strcmp(op_function(), "cfsetispeed") == 0)
  {
    if (!termios_include)
      warn(2002, "%s: termios.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(2)!=STRUCT_TYPE)	/* check argument's type:struct */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (strcmp(op_base_name(2), "termios") != 0)
        warn(2004, "%s: argument with incorrect type.", op_function()); 
      else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
      /*else if (op_base(1)!=DEFINED_TYPE)*/	/* speed_t type */
      /*  warn(2004, "%s: argument with incorrect type.", op_function());
      else if (strcmp(op_base_name(1), "speed_t") != 0)
        warn(2004, "%s: argument with incorrect type.", op_function());*/
    }
  }
  else if (strcmp(op_function(), "cfsetospeed") == 0)
  {
    if (!termios_include)
      warn(2002, "%s: termios.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(2)!=STRUCT_TYPE)	/* check argument's type:struct */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (strcmp(op_base_name(2), "termios") != 0)
        warn(2004, "%s: argument with incorrect type.", op_function()); 
      else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
      /*else if (op_base(1)!=LONG_TYPE)	*//* speed_t type */
       /* warn(2004, "%s: argument with incorrect type.", op_function());*/
    }
  }
  else if (strcmp(op_function(), "chdir") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  }
  else if (strcmp(op_function(), "chmod") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!sys_stat_include)
      warn(2002, "%s: sys/stat.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
    /*  if (op_base(1)!=LONG_TYPE)*/	/* check argument's type:mode_t */
     /*   warn(2004, "%s: argument with incorrect type.", op_function());*/
      if (op_base(2)!=CHAR_TYPE)			/* char type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  }
  else if (strcmp(op_function(), "chown") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (op_operands!=3)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      /*if (op_base(1)!=LONG_TYPE)*/	/* check argument's type:gid_t */
        /*warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_base(2)!=LONG_TYPE)*/	/* check argument's type:uid_t */
      /*  warn(2004, "%s: argument with incorrect type.", op_function());*/
      if (op_base(3)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(3, op_levels(3))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(3, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(3, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  }
  else if (strcmp(op_function(), "close") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=INT_TYPE)	/* check argument's type:int */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  }
  else if (strcmp(op_function(), "closedir") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys_types.h is not included.", op_function());
    if (!dirent_include)
      warn(2002, "%s: dirent.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
    { 
      if (op_base(1)!=EXTRA_PTR_TYPE)*/ /* check argument's type: DIR */
        /*warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
        /*warn(2004, "%s: argument with incorrect type.", op_function());
    }*/
  }
  else if (strcmp(op_function(), "creat") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!sys_stat_include)
      warn(2002, "%s: sys/stat.h is not included.", op_function());
    if (!fcntl_include)
      warn(2002, "%s: fcntl.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      /*if (op_base(1)!=LONG_TYPE)*/	/* check argument's type:mode_t */
      /*  warn(2004, "%s: argument with incorrect type.", op_function());*/
      if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  }
  else if (strcmp(op_function(), "ctermid") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  }
  else if (strcmp(op_function(), "cuserid") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  }
  if (strcmp(op_function(), "dup") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=INT_TYPE)	/* check argument's type:int */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  }
  else if (strcmp(op_function(), "dup2") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=INT_TYPE)	/* check argument's type:int */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_base(2)!=INT_TYPE)	/* check argument's type:int */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  } 
  else if (strcmp(op_function(), "execl") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands<=2)     /* check the minimum number of parameters. */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    {
      if (op_base(op_operands-1)!=CHAR_TYPE) /* type: char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(op_operands-1, op_levels(op_operands-1))!=1) /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(op_operands-1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(op_operands-1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
      else if (op_base(op_operands)!=CHAR_TYPE) /* type char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(op_operands, op_levels(op_operands))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());	  
      else if (op_level(op_operands, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(op_operands, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "execle") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands<=2)     /* check the minimum number of parameters. */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    {
      if (op_base(op_operands-1)!=CHAR_TYPE) /* type: char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(op_operands-1, op_levels(op_operands-1))!=1) /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(op_operands-1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(op_operands-1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
      else if (op_base(op_operands)!=CHAR_TYPE) /* type char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(op_operands, op_levels(op_operands))!=1) /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());	  
      else if (op_level(op_operands, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(op_operands, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "execlp") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands<=2)     /* check the minimum number of parameters. */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    {
      if (op_base(op_operands-1)!=CHAR_TYPE) /* type: char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(op_operands-1, op_levels(op_operands-1))!=1) /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(op_operands-1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(op_operands-1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
      else if (op_base(op_operands)!=CHAR_TYPE) /* type char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(op_operands, op_levels(op_operands))!=1) /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());	  
      else if (op_level(op_operands, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(op_operands, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "execv") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
      else if (op_base(2)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "execve") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=3)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
      else if (op_base(2)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
      else if (op_base(3)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(3, op_levels(3))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(3, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(3, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "execvp") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
      else if (op_base(2)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "_exit") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=INT_TYPE)	/* check argument's type:int */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  } 
  if (strcmp(op_function(), "fcntl") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (!fcntl_include)
      warn(2002, "%s: fcntl.h is not included.", op_function());
    if (op_operands<=2)     /* check the minimum number of parameters. */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    {
      if (op_base(op_operands-1)!=INT_TYPE) /* type: int */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_base(op_operands)!=INT_TYPE) /* type int */
        warn(2004, "%s: argument with incorrect type.", op_function());  
    }
  }
  else if (strcmp(op_function(), "fdopen") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrrct type.", op_function());
      else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
      else if (op_base(2)!=INT_TYPE) /* check argument's type: int */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  } 
  else if (strcmp(op_function(), "fileno") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
    { 
      if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
        /*warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
          /*warn(2004, "%s: argument with incorrect type.", op_function());
    }*/
  } 
  else if (strcmp(op_function(), "fork") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=0)		/* check the number of parameters:void */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
  } 
  else if (strcmp(op_function(), "fpathconf") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=INT_TYPE)	/* check argument's type:int */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_base(2)!=INT_TYPE)	/* check argument's type:int */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  } 
  else if (strcmp(op_function(), "fstat") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!sys_stat_include)
      warn(2002, "%s: sys/stat.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=STRUCT_TYPE)	/* check argument's type:struct */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (strcmp(op_base_name(1), "stat") != 0)
        warn(2004, "%s: argument with incorrect type.", op_function()); 
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_base(2)!=INT_TYPE)	/* check argument's type:int */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  } 
  else if (strcmp(op_function(), "getcwd") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      /*if (op_base(1)!=LONG_TYPE)*/	/* check argument's type:size_t */
      /*{
        if (op_base(1)==UINT_TYPE)	;  
        else
    	  warn(2004, "%s: argument with incorrect type.", op_function());
      }*/
      if (op_base(2)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "getegid") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=0)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
  } 
  else if (strcmp(op_function(), "getenv") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "geteuid") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=0)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
  } 
  else if (strcmp(op_function(), "getgid") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=0)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
  } 
  else if (strcmp(op_function(), "getgrgid") == 0)
  {
    if (!grp_include)
      warn(2002, "%s: grp.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
    { 
      if (op_base(1)!=LONG_TYPE)*/	/* check argument's type:gid_t */
       /* warn(2004, "%s: argument with incorrect type.", op_function());
    }*/
  } 
  if (strcmp(op_function(), "getgrnam") == 0)
  {
    if (!grp_include)
      warn(2002, "%s: grp.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  if (strcmp(op_function(), "getgroups") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      /*if (op_base(1)!=LONG_TYPE)*/	/* check argument's type:gid_t */
        /*warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
      /*{
        if (op_level(1, 0)!=ARRAY) */   /* an array type */
          /*warn(2004, "%s: argument with incorrect type.", op_function());
      }*/
      if (op_base(2)!=INT_TYPE)	/* check argument's type: int */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  } 
  if (strcmp(op_function(), "getlogin") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=0)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
  } 
  else if (strcmp(op_function(), "getpgrp") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=0)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
  } 
  else if (strcmp(op_function(), "getpid") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=0)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
  } 
  else if (strcmp(op_function(), "getppid") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=0)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
  } 
  else if (strcmp(op_function(), "getpwnam") == 0)
  {
    if (!pwd_include)
      warn(2002, "%s: pwd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "getpwuid") == 0)
  {
    if (!pwd_include)
      warn(2002, "%s: pwd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
   /* else
    { 
      if (op_base(1)!=LONG_TYPE)*/	/* check argument's type:uid_t */
       /* warn(2004, "%s: argument with incorrect type.", op_function());
    }*/
  } 
  else if (strcmp(op_function(), "getuid") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=0)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
  }
  if (strcmp(op_function(), "isatty") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=INT_TYPE)	/* check argument's type:int */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  } 
  else if (strcmp(op_function(), "kill") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!signal_include)
      warn(2002, "%s: signal.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=INT_TYPE)	/* check argument's type:int */
        warn(2004, "%s: argument with incorrect type.", op_function());
      /*else if (op_base(2)!=LONG_TYPE)*/	/* check argument's type:pid_t */
        /*warn(2004, "%s: argument with incorrect type.", op_function());*/
    }
  } 
  else if (strcmp(op_function(), "link") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
      else if (op_base(2)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "lseek") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=3)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=INT_TYPE)	/* check argument's type:int */
        warn(2004, "%s: argument with incorrect type.", op_function());
      /*else if (op_base(2)!=LONG_TYPE)*/	/* check argument's type:off_t */
        /*warn(2004, "%s: argument with incorrect type.", op_function());*/
      else if (op_base(3)!=INT_TYPE)   /* int type */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  } 
  else if (strcmp(op_function(), "mkdir") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!sys_stat_include)
      warn(2002, "%s: sys/stat.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      /*if (op_base(1)!=LONG_TYPE)*/	/* check argument's type:mode_t */
        /*warn(2004, "%s: argument with incorrect type.", op_function());*/
      if (op_base(2)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "mkfifo") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!sys_stat_include)
      warn(2002, "%s: sys/stat.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      /*if (op_base(1)!=LONG_TYPE)*/	/* check argument's type:mode_t */
      /*  warn(2004, "%s: argument with incorrect type.", op_function());*/
      if (op_base(2)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "open") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!sys_stat_include)
      warn(2002, "%s: sys/stat.h is not included.", op_function());
    if (!fcntl_include)
      warn(2002, "%s: fcntl.h is not included.", op_function());
    if (op_operands<2)     /* check the minimum number of parameters. */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    {
      if (op_base(op_operands-1)!=INT_TYPE) /* type: int */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_base(op_operands)!=CHAR_TYPE) /* type char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(op_operands, op_levels(op_operands))!=1) /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());	  
      else if (op_level(op_operands, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(op_operands, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }	
  } 
  else if (strcmp(op_function(), "opendir") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!dirent_include)
      warn(2002, "%s: dirent.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "pathconf") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      /*if (op_base(1)!=LONG_TYPE)*/	/* check argument's type:mode_t */
      /*  warn(2004, "%s: argument with incorrect type.", op_function());*/
      if (op_base(2)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "pause") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=0)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
  } 
  else if (strcmp(op_function(), "pipe") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=ARRAY)    /* a array type */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  } 
  else if (strcmp(op_function(), "read") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=3)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      /*if (op_base(1)!=LONG_TYPE)*/	/* check argument's type:size_t */
      /*{
        if (op_base(1)==UINT_TYPE)	;  
        else
    	  warn(2004, "%s: argument with incorrect type.", op_function());
      }*/
      if (op_base(2)!=VOID_TYPE)	/* check argument's type: void */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
      else if (op_base(3)!=INT_TYPE)	/* check argument's type: int */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  } 
  else if (strcmp(op_function(), "readdir") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: systypes.h is not included.", op_function());
    if (!dirent_include)
      warn(2002, "%s: dirent.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
    { 
      if (op_base(1)!=EXTRA_PTR_TYPE)*/	/* check argument's type: DIR */
        /*warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
        /*warn(2004, "%s: argument with incorrect type.", op_function());
    }*/
  }
  else if (strcmp(op_function(), "rename") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(1, op_levels(1))!=1)	/* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
      else if (op_base(2)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  } 
  else if (strcmp(op_function(), "rewinddir") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: systypes.h is not included.", op_function());
    if (!dirent_include)
      warn(2002, "%s: dirent.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
    { 
      if (op_base(1)!=EXTRA_PTR_TYPE)*/	/* check argument's type: DIR */
        /*warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
        /*warn(2004, "%s: argument with incorrect type.", op_function());
    }*/
  } 
  else if (strcmp(op_function(), "rmdir") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=CHAR_TYPE)	/* check argument's type:char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  }
  if (strcmp(op_function(), "setgid") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: systypes.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: gid_t */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	}*/
  } 
  else if (strcmp(op_function(), "setpgid") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: systypes.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: pid_t */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_base(2)!=LONG_TYPE)*/	/* check argument's type: pid_t */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	}*/
  } 
  if (strcmp(op_function(), "setsid") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: systypes.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=0)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
  } 
  else if (strcmp(op_function(), "setuid") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: systypes.h is not included.", op_function());
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
   /* else
	{ 
 	  if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: uid_t */
	   /* warn(2004, "%s: argument with incorrect type.", op_function());
 	}*/
  } 
  else if (strcmp(op_function(), "sigaction") == 0)
  {
    if (!signal_include)
      warn(2002, "%s: signal.h is not included.", op_function());
    if (op_operands!=3)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=VOID_TYPE)	/* check argument's type: NULL */
      {
        if (op_base(1)!=STRUCT_TYPE)	/* check argument's type: struct */
          warn(2004, "%s: argument with incorrect type.", op_function());
        else if (strcmp(op_base_name(1), "sigaction") != 0)
          warn(2004, "%s: argument with incorrect type.", op_function());
        else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
      if (op_base(2)!=STRUCT_TYPE)	/* check argument's type: struct */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_base(3)!=INT_TYPE)	/* check argument's type: int */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  } 
  if (strcmp(op_function(), "sigaddset") == 0)
  {
    if (!signal_include)
      warn(2002, "%s: signal.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_base(2)!=STRUCT_TYPE)	/* check argument's type: struct */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (strcmp(op_base_name(2), "sigset_t") != 0)
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "sigdelset") == 0)
  {
    if (!signal_include)
      warn(2002, "%s: signal.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    {
      if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_base(2)!=STRUCT_TYPE)	/* check argument's type: struct */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (strcmp(op_base_name(2), "sigset_t") != 0)
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "sigemptyset") == 0)
  {
    if (!signal_include)
      warn(2002, "%s: signal.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=STRUCT_TYPE)	/* check argument's type: struct */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (strcmp(op_base_name(1), "sigset_t") != 0)
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    } 
  } 
  else if (strcmp(op_function(), "sigfillset") == 0)
  {
    if (!signal_include)
      warn(2002, "%s: signal.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=STRUCT_TYPE)	/* check argument's type: struct */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (strcmp(op_base_name(1), "sigset_t") != 0)
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "sigismember") == 0)
  {
    if (!signal_include)
      warn(2002, "%s: signal.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_base(2)!=STRUCT_TYPE)	/* struct type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (strcmp(op_base_name(2), "sigset_t") != 0)
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(2, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(2, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "siglongjmp") == 0)
  {
    if (!setjmp_include)
      warn(2002, "%s: setjmp.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
        warn(2004, "%s: argument with incorrect type.", op_function());
      /*else if (op_base(2)!=EXTRA_UINT_TYPE)*/	/* check argument's type: sigjmp_buf */
        /*warn(2004, "%s: argument with incorrect type.", op_function());*/
    }
  } 
  else if (strcmp(op_function(), "sigpending") == 0)
  {
    if (!signal_include)
      warn(2002, "%s: signal.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=STRUCT_TYPE)	/* struct type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (strcmp(op_base_name(1), "sigset_t") != 0)
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(1, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  } 
  else if (strcmp(op_function(), "sigprocmask") == 0)
  {
    if (!signal_include)
      warn(2002, "%s: signal.h is not included.", op_function());
    if (op_operands!=3)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=STRUCT_TYPE)	/* struct type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
          else if (strcmp(op_base_name(1), "sigset_t") != 0)
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	  else if (op_base(2)!=STRUCT_TYPE)	/* struct type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
          else if (strcmp(op_base_name(2), "sigset_t") != 0)
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(2, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
	  else if (op_base(3)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  } 
  else if (strcmp(op_function(), "sigsetjmp") == 0)
  {
    if (!setjmp_include)
      warn(2002, "%s: setjmp.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  /*else if (op_base(2)!=EXTRA_UINT_TYPE)*/	/* check argument's type: sigjmp_buf */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());*/
 	}
  } 
  else if (strcmp(op_function(), "sigsuspend") == 0)
  {
    if (!signal_include)
      warn(2002, "%s: signal.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=STRUCT_TYPE)	/* struct type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
          else if (strcmp(op_base_name(1), "sigset_t") != 0)
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  } 
  else if (strcmp(op_function(), "sleep") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=UINT_TYPE)	/* check argument's type: unsigned int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  } 
  else if (strcmp(op_function(), "stat") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!sys_stat_include)
      warn(2002, "%s: sys/stat.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=STRUCT_TYPE)	/* check argument's type: struct */
	    warn(2004, "%s: argument with incorrect type.", op_function());
          else if (strcmp(op_base_name(1), "stat")!=0)
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	  else if (op_base(2)!=CHAR_TYPE)	/* check argument's type:char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(2, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  } 
  else if (strcmp(op_function(), "sysconf") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }
  if (strcmp(op_function(), "tcdrain") == 0)
  {
    if (!termios_include)
      warn(2002, "%s: termios.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  } 
  else if (strcmp(op_function(), "tcflow") == 0)
  {
    if (!termios_include)
      warn(2002, "%s: termios.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_base(2)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  } 
  else if (strcmp(op_function(), "tcflush") == 0)
  {
    if (!termios_include)
      warn(2002, "%s: termios.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_base(2)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  } 
  else if (strcmp(op_function(), "tcgetattr") == 0)
  {
    if (!termios_include)
      warn(2002, "%s: termios.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=STRUCT_TYPE)	/* check argument's type: struct */
	    warn(2004, "%s: argument with incorrect type.", op_function());
          else if (strcmp(op_base_name(1), "termios") != 0)
	    warn(2004, "%s: argument with incorrect type.", op_function()); 
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
            warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_base(2)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  } 
  else if (strcmp(op_function(), "tcgetpgrp") == 0)
  {
    if (!termios_include)
      warn(2002, "%s: termios.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  } 
  else if (strcmp(op_function(), "tcsendbreak") == 0)
  {
    if (!termios_include)
      warn(2002, "%s: termios.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_base(2)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  } 
  else if (strcmp(op_function(), "tcsetattr") == 0)
  {
    if (!termios_include)
      warn(2002, "%s: termios.h is not included.", op_function());
    if (op_operands!=3)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=STRUCT_TYPE)	/* check argument's type: struct */
	    warn(2004, "%s:1 argument with incorrect type.", op_function());
          else if (strcmp(op_base_name(1), "termios") != 0)
	    warn(2004, "%s: argument with incorrect type.", op_function()); 
          else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s:2 argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
            warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_base(2)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s:4 argument with incorrect type.", op_function());
	  else if (op_base(3)!=INT_TYPE)    /* check argument's type: int */
	    warn(2004, "%s:5 argument with incorrect type.", op_function());
 	}
  } 
  else if (strcmp(op_function(), "tcsetpgrp") == 0)
  {
    if (!termios_include)
      warn(2002, "%s: termios.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  /*if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: pid_t */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());*/
 	  if (op_base(2)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  } 
  else if (strcmp(op_function(), "time") == 0)
  {
    if (!time_include)
      warn(2002, "%s: time.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: time_t */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
          /*{
            if (op_level(1, 0)!=ARRAY)*/    /* an array type */
              /*warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}*/
  } 
  else if (strcmp(op_function(), "times") == 0)
  {
    if (!sys_times_include)
      warn(2002, "%s: sys/times.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=STRUCT_TYPE)	/* check argument's type: struct */
	    warn(2004, "%s: argument with incorrect type.", op_function());
          else if (strcmp(op_base_name(1), "tms")!=0)
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
            warn(2004, "%s: argument with incorrect type.", op_function());
	}
  } 
  else if (strcmp(op_function(), "ttyname") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  } 
  else if (strcmp(op_function(), "tzset") == 0)
  {
    if (!time_include)
      warn(2002, "%s: time.h is not included.", op_function());
    if (op_operands!=0)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
  } 
  if (strcmp(op_function(), "umask") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!sys_stat_include)
      warn(2002, "%s: sys/stat.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: mode_t */
	  /*  warn(2004, "%s: argument with incorrect type.", op_function());
 	}*/
  } 
  else if (strcmp(op_function(), "uname") == 0)
  {
    if (!sys_utsname_include)
      warn(2002, "%s: sys/utsname.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=STRUCT_TYPE)	/* check argument's type: struct */
	    warn(2004, "%s: argument with incorrect type.", op_function());
          else if (strcmp(op_base_name(1), "utsname")!=0)
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
            warn(2004, "%s: argument with incorrect type.", op_function());
	}
  } 
  else if (strcmp(op_function(), "unlink") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  } 
  else if (strcmp(op_function(), "utime") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!utime_include)
      warn(2002, "%s: utime.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=STRUCT_TYPE)	/* check argument's type: struct */
	    warn(2004, "%s: argument with incorrect type.", op_function());
          else if (strcmp(op_base_name(1), "utimbuf")!=0)
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
          else if (op_level(1, 0)!=POINTER)    /* a pointer type */
            warn(2004, "%s: argument with incorrect type.", op_function());
          else if (op_base(2)!=CHAR_TYPE)	/* check argument's type:char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(2, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  } 
  else if (strcmp(op_function(), "wait") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!sys_wait_include)
      warn(2002, "%s: sys/wait.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  } 
  else if (strcmp(op_function(), "waitpid") == 0)
  {
    if (!sys_types_include)
      warn(2002, "%s: sys/types.h is not included.", op_function());
    if (!sys_wait_include)
      warn(2002, "%s: sys/wait.h is not included.", op_function());
    if (op_operands!=3)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_base(2)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(2, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
      /*else if (op_base(3)!=LONG_TYPE) */   /* check argument's type: pid_t */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());*/
 	}
  } 
  else if (strcmp(op_function(), "write") == 0)
  {
    if (!unistd_include)
      warn(2002, "%s: unistd.h is not included.", op_function());
    if (op_operands!=3)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  /*if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: size_t */
      /*{
        if (op_base(1)==UINT_TYPE)	;  
	    else
    	  warn(2004, "%s: argument with incorrect type.", op_function());
      }*/
 	  if (op_base(2)!=VOID_TYPE)	/* check argument's type: void */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(2, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
	  else if (op_base(3)!=INT_TYPE)    /* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
}

/* check the header files required for ANSI C function only */
if (op_call)
{
  if (strcmp(op_function(), "abort") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=0)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
  }       
  else if (strcmp(op_function(), "abs") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "acos") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "asctime") == 0)
  {
    if (!time_include)
      warn(2002, "%s: time.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=STRUCT_TYPE)	/* check argument's type: struct */
	    warn(2004, "%s: argument with incorrect type.", op_function());
          else if (strcmp(op_base_name(1), "tm")!=0)
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }       
  else if (strcmp(op_function(), "asin") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "assert") == 0)
  {
    if (!assert_include)
      warn(2002, "%s: assert.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "atan") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "atan2") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_base(2)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "atof") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }       
  else if (strcmp(op_function(), "atoi") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  else if (strcmp(op_function(), "atol") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
   }       
  else if (strcmp(op_function(), "bsearch") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=5)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
        warn(2004, "%s: argument with incorrect type.", op_function());
      /*else if (op_base(2)!=UINT_TYPE)*/	/* type: size_t */  
        /*warn(2004, "%s: argument with incorrect type.", op_function());*/
      /*if (op_base(3)!=UINT_TYPE)*/	/* type: size_t  */  
        /*warn(2004, "%s: argument with incorrect type.", op_function());*/
      else if (op_base(4)!=VOID_TYPE)	/* type void */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(4, op_levels(4))!=1)   /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(4, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(4, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
      else if (op_base(5)!=VOID_TYPE)	/* type void */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(5, op_levels(5))!=1)	/* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(5, 0)!=POINTER)    /* a pointer type */
      {
        if (op_level(5, 0)!=ARRAY)    /* an array type */
          warn(2004, "%s: argument with incorrect type.", op_function());
      }
    }
  }       
  else if (strcmp(op_function(), "calloc") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
    { 
      if (op_base(1)!=UINT_TYPE)*/	/* type: size_t */  
        /*warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_base(2)!=UINT_TYPE)*/ 	/* type : size_t */ 
        /*warn(2004, "%s: argument with incorrect type.", op_function());
    }*/
  }       
  else if (strcmp(op_function(), "ceil") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
   }       
  else if (strcmp(op_function(), "clearerr") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
            /*warn(2004, "%s: argument with incorrect type.", op_function());
	}*/
   }       
  else if (strcmp(op_function(), "cos") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
   }       
  else if (strcmp(op_function(), "cosh") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
   }       
  else if (strcmp(op_function(), "ctime") == 0)
  {
    if (!time_include)
      warn(2002, "%s: time.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: time_t */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)*/   /* const type */
	    /*warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
          /*{
            if (op_level(1, 0)!=ARRAY)*/    /* an array type */
              /*warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}*/
   }       
  else if (strcmp(op_function(), "exit") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
   }       
  else if (strcmp(op_function(), "exp") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
   }       
  else if (strcmp(op_function(), "fabs") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
   }       
  else if (strcmp(op_function(), "fclose") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
              /*warn(2004, "%s: argument with incorrect type.", op_function());
	}*/
   }       
  else if (strcmp(op_function(), "feof") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
         /* {
            if (op_level(1, 0)!=ARRAY)*/    /* an array type */
              /*warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}*/
  }       
  else if (strcmp(op_function(), "ferror") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
              /*warn(2004, "%s: argument with incorrect type.", op_function());
	}*/
   }       
  else if (strcmp(op_function(), "fflush") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
              /*warn(2004, "%s: argument with incorrect type.", op_function());
	}*/
  }       
  else if (strcmp(op_function(), "fgetc") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
              /*warn(2004, "%s: argument with incorrect type.", op_function());
	}*/
  }       
  else if (strcmp(op_function(), "fgets") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=3)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  /*if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER) */   /* a pointer type */
              /*warn(2004, "%s: argument with incorrect type.", op_function());*/
          if (op_base(2)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_base(3)!=CHAR_TYPE) /* type char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(3, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(3, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  else if (strcmp(op_function(), "floor") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
   }       
  else if (strcmp(op_function(), "fmod") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_base(2)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "fopen") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	  else if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(2, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }       
  else if (strcmp(op_function(), "fprintf") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands<2)     /* check the minimum number of parameters. */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    {
      if (op_base(op_operands-1)!=CHAR_TYPE) /* type: char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(op_operands-1, op_levels(op_operands-1))!=1) /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(op_operands-1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(op_operands-1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
      /*else if (op_base(op_operands)!=EXTRA_UINT_TYPE)*/ /* type FILE */
        /*warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(op_operands, 0)!=POINTER)*/    /* a pointer type */
        /*warn(2004, "%s: argument with incorrect type.", op_function());*/
    }
  }       
  else if (strcmp(op_function(), "fputc") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  /*if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
            /*warn(2004, "%s: argument with incorrect type.", op_function());*/
	  if (op_base(2)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "fputs") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  /*if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
            /*warn(2004, "%s: argument with incorrect type.", op_function());*/
 	  if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(2, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  else if (strcmp(op_function(), "fread") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=4)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  /*if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
            /*warn(2004, "%s: argument with incorrect type.", op_function());*/
	  /*else if (op_base(2)!=LONG_TYPE)*/	/* check argument's type: size_t */
      /*{
        if (op_base(2)==UINT_TYPE)	;  
	    else
    	  warn(2004, "%s: argument with incorrect type.", op_function());
      }*/
	  /*else if (op_base(3)!=LONG_TYPE)*/	/* type size_t */
      /*{
        if (op_base(3)==UINT_TYPE)	;  
	    else
    	  warn(2004, "%s: argument with incorrect type.", op_function());
      }*/
	  if (op_base(4)!=VOID_TYPE)	/* type void */
	    warn(2004, "%s: argument with incorrect type.", op_function()); 
 	  else if (op_level(4, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(4, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  else if (strcmp(op_function(), "free") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=VOID_TYPE)	/* check argument's type: void */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }       
  else if (strcmp(op_function(), "freopen") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=3)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  /*if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());	  
	  else if (op_level(1, 0)!=POINTER) */   /* a pointer type */
              /*warn(2004, "%s: argument with incorrect type.", op_function());*/
	  if (op_base(2)!=CHAR_TYPE)		/* type char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(2, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	  else if (op_base(3)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(3, op_levels(3))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(3, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(3, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }       
  else if (strcmp(op_function(), "frexp") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
      else if (op_base(2)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "fscanf") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands<2)     /* check the minimum number of parameters. */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{
	  if (op_base(op_operands-1)!=CHAR_TYPE) /* type: char */
            warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(op_operands-1, op_levels(op_operands-1))!=1) /* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(op_operands-1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(op_operands-1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
      /*else if (op_base(op_operands)!=EXTRA_UINT_TYPE)*/ /* type FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());*/ 
	  /*else if (op_level(op_operands, 0)!=POINTER) */   /* a pointer type */
              /*warn(2004, "%s: argument with incorrect type.", op_function());*/
	}
  }       
  else if (strcmp(op_function(), "fseek") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=3)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_base(2)!=LONG_TYPE)	/* check argument's type: long */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  /*else if (op_base(3)!=EXTRA_UINT_TYPE)*/	/* type FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(3, 0)!=POINTER)*/    /* a pointer type */
            /*warn(2004, "%s: argument with incorrect type.", op_function());*/
 	}
  }       
  else if (strcmp(op_function(), "ftell") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=EXTRA_UINT_TYPE)*/ /* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
            /*warn(2004, "%s: argument with incorrect type.", op_function());
	}*/
  }       
  else if (strcmp(op_function(), "fwrite") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=4)  /* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  /*if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)*/  /* a pointer type */
            /*warn(2004, "%s: argument with incorrect type.", op_function());*/
	  /*else if (op_base(2)!=LONG_TYPE)*/        /* size_t type */
      /*{
        if (op_base(2)==UINT_TYPE)	;  
	    else
    	  warn(2004, "%s: argument with incorrect type.", op_function());
      }
 	  else if (op_base(3)!=LONG_TYPE)*/	/* check argument's type: size_t */
      /*{
        if (op_base(3)==UINT_TYPE)	;
        else
    	  warn(2004, "%s: argument with incorrect type.", op_function());
      }*/	  
      if (op_base(4)!=VOID_TYPE)   /* void type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level_flags(4, op_levels(4))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(4, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(4, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }       
  else if (strcmp(op_function(), "getc") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
              /*warn(2004, "%s: argument with incorrect type.", op_function());
 	}*/
  }       
  else if (strcmp(op_function(), "getchar") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=VOID_TYPE)	/* check argument's type: void */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "getenv") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  else if (strcmp(op_function(), "gets") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  else if (strcmp(op_function(), "gmtime") == 0)
  {
    if (!time_include)
      warn(2002, "%s: time.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: time_t */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)*/   /* const type */
	    /*warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
          /*{
            if (op_level(1, 0)!=ARRAY)*/    /* an array type */
              /*warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}*/
  }       
  else if (strcmp(op_function(), "isalnum") == 0)
  {
    if (!ctype_include)
      warn(2002, "%s: ctype.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "isalpha") == 0)
  {
    if (!ctype_include)
      warn(2002, "%s: ctype.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "iscntrl") == 0)
  {
    if (!ctype_include)
      warn(2002, "%s: ctype.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "isdigit") == 0)
  {
    if (!ctype_include)
      warn(2002, "%s: ctype.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "isgraph") == 0)
  {
    if (!ctype_include)
      warn(2002, "%s: ctype.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "islower") == 0)
  {
    if (!ctype_include)
      warn(2002, "%s: ctype.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "isprint") == 0)
  {
    if (!ctype_include)
      warn(2002, "%s: ctype.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "ispunct") == 0)
  {
    if (!ctype_include)
      warn(2002, "%s: ctype.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "isspace") == 0)
  {
    if (!ctype_include)
      warn(2002, "%s: ctype.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "isupper") == 0)
  {
    if (!ctype_include)
      warn(2002, "%s: ctype.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "isxdigit") == 0)
  {
    if (!ctype_include)
      warn(2002, "%s: ctype.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "ldexp") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_base(2)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "localtime") == 0)
  {
    if (!time_include)
      warn(2002, "%s: time.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: time_t */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)*/   /* const type */
	    /*warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
          /*{
            if (op_level(1, 0)!=ARRAY)*/    /* an array type */
              /*warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}*/
  }       
  else if (strcmp(op_function(), "log") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "log10") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "longjmp") == 0)
  {
    if (!setjmp_include)
      warn(2002, "%s: setjmp.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  /*else if (op_base(2)!=EXTRA_UINT_TYPE)*/	/* type: jmp_buf */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());*/
 	}
  }       
  else if (strcmp(op_function(), "malloc") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: size_t */
      /*{
        if (op_base(1)==UINT_TYPE)	;  
	    else
    	  warn(2004, "%s: argument with incorrect type.", op_function());
      }
 	}*/
  }       
  else if (strcmp(op_function(), "mktime") == 0)
  {
    if (!time_include)
      warn(2002, "%s: time.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=STRUCT_TYPE)	/* check argument's type: struct */
	    warn(2004, "%s: argument with incorrect type.", op_function());
          else if (strcmp(op_base_name(1), "tm")!=0)
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  else if (strcmp(op_function(), "modf") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
	  else if (op_base(2)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "perror") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(1, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  else if (strcmp(op_function(), "pow") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_base(2)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "printf") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands<1)     /* check the minimum number of parameters. */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{
	  if (op_base(op_operands)!=CHAR_TYPE) /* type: char */
            warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(op_operands, op_levels(op_operands))!=1) /* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());	  
	  else if (op_level(op_operands, 0)!=POINTER)    /* a pointer type */
          {
            if (op_level(op_operands, 0)!=ARRAY)    /* an array type */
              warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  else if (strcmp(op_function(), "putc") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  /*if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());*/
 	  if (op_base(2)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	}
  }       
  else if (strcmp(op_function(), "putchar") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "puts") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  else if (strcmp(op_function(), "qsort") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=4)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  /*else if (op_base(2)!=LONG_TYPE)*/	/* check argument's type: size_t */
      /*{
        if (op_base(2)==UINT_TYPE)	;  
	    else
    	  warn(2004, "%s: argument with incorrect type.", op_function());
      }
	  else if (op_base(3)!=LONG_TYPE)*/	/* size_t type */
      /*{
        if (op_base(3)==UINT_TYPE)	;  
	    else
    	  warn(2004, "%s: argument with incorrect type.", op_function());
      }*/
	  else if (op_base(4)!=VOID_TYPE)	/* void type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(4, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(4, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  else if (strcmp(op_function(), "rand") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=VOID_TYPE)	/* check argument's type: void */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  else if (strcmp(op_function(), "realloc") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  /*if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: size_t */
      /*{
        if (op_base(1)==UINT_TYPE)	;  
	    else
    	  warn(2004, "%s: argument with incorrect type.", op_function());
      }*/
 	  if (op_base(2)!=VOID_TYPE)	/* check argument's type: void */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  else if (strcmp(op_function(), "remove") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }       
  else if (strcmp(op_function(), "rename") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	  else if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  else if (strcmp(op_function(), "rewind") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
	}*/
  }       
  else if (strcmp(op_function(), "scanf") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands<1)     /* check the minimum number of parameters. */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{
	  if (op_base(op_operands)!=CHAR_TYPE) /* type: char */
        warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(op_operands, op_levels(op_operands))!=1) /* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());  
	  else if (op_level(op_operands, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(op_operands, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  else if (strcmp(op_function(), "setbuf") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	  /*else if (op_base(2)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(2, 0)!=POINTER)*/    /* a pointer type */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());*/
	}
  }       
  else if (strcmp(op_function(), "setjmp") == 0)
  {
    if (!setjmp_include)
      warn(2002, "%s: setjmp.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* type: jmp_buf */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
 	}*/
  }       
  else if (strcmp(op_function(), "setlocale") == 0)
  {
    if (!locale_include)
      warn(2002, "%s: locale.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	  else if (op_base(2)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  if (strcmp(op_function(), "sin") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  if (strcmp(op_function(), "sinh") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    { 
      if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
        warn(2004, "%s: argument with incorrect type.", op_function());
    }
  }       
  if (strcmp(op_function(), "sprintf") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands<2)     /* check the minimum number of parameters. */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
    {
      if (op_base(op_operands-1)!=CHAR_TYPE) /* type: char */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level_flags(op_operands-1, op_levels(op_operands-1))!=1) /* const type */
        warn(2004, "%s: argument with incorrect type.", op_function());
      else if (op_level(op_operands-1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(op_operands-1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
      else if (op_base(op_operands)!=CHAR_TYPE) /* type char */
        warn(2004, "%s: argument with incorrect type.", op_function());	  
      else if (op_level(op_operands, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(op_operands, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
    }	
  }       
  if (strcmp(op_function(), "sqrt") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  if (strcmp(op_function(), "srand") == 0)
  {
    if (!stdlib_include)
      warn(2002, "%s: stdlib.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=UINT_TYPE)	/* type: unsigned int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }       
  if (strcmp(op_function(), "sscanf") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands<=2)     /* check the minimum number of parameters. */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{
	  if (op_base(op_operands-1)!=CHAR_TYPE) /* type: char */
        warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(op_operands-1, op_levels(op_operands-1))!=1) /* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(op_operands-1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(op_operands-1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
      else if (op_base(op_operands)!=CHAR_TYPE) /* type char */
	    warn(2004, "%s: argument with incorrect type.", op_function());	  
	  else if (op_level(op_operands, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(op_operands, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  if (strcmp(op_function(), "strcat") == 0)
  {
    if (!string_include)
      warn(2002, "%s: string.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	  else if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  if (strcmp(op_function(), "strchr") == 0)
  {
    if (!string_include)
      warn(2002, "%s: string.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  if (strcmp(op_function(), "strcmp") == 0)
  {
    if (!string_include)
      warn(2002, "%s: string.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	  else if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  if (strcmp(op_function(), "strcpy") == 0)
  {
    if (!string_include)
      warn(2002, "%s: string.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	  else if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  if (strcmp(op_function(), "strcspn") == 0)
  {
    if (!string_include)
      warn(2002, "%s: string.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	  else if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  if (strcmp(op_function(), "strftime") == 0)
  {
    if (!time_include)
      warn(2002, "%s: time.h is not included.", op_function());
    if (op_operands!=4)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=STRUCT_TYPE)	/* check argument's type: struct */
	    warn(2004, "%s: argument with incorrect type.", op_function());
          else if (strcmp(op_base_name(1), "tm")!=0)
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	  /*else if (op_base(3)!=LONG_TYPE)*/	/* type size_t */
      /*{
        if (op_base(3)==UINT_TYPE)	;  
	    else
    	  warn(2004, "%s: argument with incorrect type.", op_function());
      }*/
	  else if (op_base(4)!=CHAR_TYPE)	/* type char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(4, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(4, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }       
  if (strcmp(op_function(), "strlen") == 0)
  {
    if (!string_include)
      warn(2002, "%s: string.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	}
  }       
  if (strcmp(op_function(), "strncat") == 0)
  {
    if (!string_include)
      warn(2002, "%s: string.h is not included.", op_function());
    if (op_operands!=3)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  /*if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: size_t */
      /*{
        if (op_base(1)==UINT_TYPE)	;  
	    else
    	  warn(2004, "%s: argument with incorrect type.", op_function());
      }*/
 	  if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
 	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
	  else if (op_base(3)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(3, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(3, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }       
  if (strcmp(op_function(), "strncmp") == 0)
  {
    if (!string_include)
      warn(2002, "%s: string.h is not included.", op_function());
    if (op_operands!=3)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  /*if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: size_t */
      /*{
        if (op_base(1)==UINT_TYPE)	;  
	    else
    	  warn(2004, "%s: argument with incorrect type.", op_function());
      }*/
 	  if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	  else if (op_base(3)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(3, op_levels(3))!=1)  /* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(3, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(3, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }       
  if (strcmp(op_function(), "strncpy") == 0)
  {
    if (!string_include)
      warn(2002, "%s: string.h is not included.", op_function());
    if (op_operands!=3)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  /*if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: size_t */
      /*{
        if (op_base(1)==UINT_TYPE)	;  
	    else
    	  warn(2004, "%s: argument with incorrect type.", op_function());
      }*/
 	  if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	  else if (op_base(3)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(3, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(3, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }       
  if (strcmp(op_function(), "strpbrk") == 0)
  {
    if (!string_include)
      warn(2002, "%s: string.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	  else if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }       
  else if (strcmp(op_function(), "strrchr") == 0)
  {
    if (!string_include)
      warn(2002, "%s: string.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	  else if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }       
  else if (strcmp(op_function(), "strspn") == 0)
  {
    if (!string_include)
      warn(2002, "%s: string.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)	/* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	  else if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }       
  else if (strcmp(op_function(), "strstr") == 0)
  {
    if (!string_include)
      warn(2002, "%s: string.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)    /* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	  else if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }
  else if (strcmp(op_function(), "strtok") == 0)
  {
    if (!string_include)
      warn(2002, "%s: string.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(1, op_levels(1))!=1)    /* const type */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	  else if (op_base(2)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level_flags(2, op_levels(2))!=1)   /* const type */
	    warn(2004, "%s: argument with incorrect type. ", op_function());
	  else if (op_level(2, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(2, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}
  }  
  else if (strcmp(op_function(), "tan") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }
  else if (strcmp(op_function(), "tanh") == 0)
  {
    if (!math_include)
      warn(2002, "%s: math.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=DOUBLE_TYPE)	/* check argument's type: double */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }  
  else if (strcmp(op_function(), "time") == 0)
  {
    if (!time_include)
      warn(2002, "%s: time.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    /*else
	{ 
 	  if (op_base(1)!=LONG_TYPE)*/	/* check argument's type: time_t */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
          /*{
	    if (op_level(1, 0)!=ARRAY)*/    /* an array type */
	      /*warn(2004, "%s: argument with incorrect type.", op_function());
          }
 	}*/
  }      
  else if (strcmp(op_function(), "tmpfile") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=VOID_TYPE)	/* check argument's type: void */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }
  else if (strcmp(op_function(), "tmpnam") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=CHAR_TYPE)	/* check argument's type: char */
	    warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)    /* a pointer type */
          {
	    if (op_level(1, 0)!=ARRAY)    /* an array type */
	      warn(2004, "%s: argument with incorrect type.", op_function());
          }
    }  
  }
  else if (strcmp(op_function(), "tolower") == 0)
  {
    if (!ctype_include)
      warn(2002, "%s: ctype.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }
  else if (strcmp(op_function(), "toupper") == 0)
  {
    if (!ctype_include)
      warn(2002, "%s: ctype.h is not included.", op_function());
    if (op_operands!=1)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  if (op_base(1)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }
  else if (strcmp(op_function(), "ungetc") == 0)
  {
    if (!stdio_include)
      warn(2002, "%s: stdio.h is not included.", op_function());
    if (op_operands!=2)		/* check the number of parameters */
      warn(2003, "%s: the number of arguments is incorrect.", op_function());
    else
	{ 
 	  /*if (op_base(1)!=EXTRA_UINT_TYPE)*/	/* check argument's type: FILE */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());
	  else if (op_level(1, 0)!=POINTER)*/    /* a pointer type */
	    /*warn(2004, "%s: argument with incorrect type.", op_function());*/
 	  if (op_base(2)!=INT_TYPE)	/* check argument's type: int */
	    warn(2004, "%s: argument with incorrect type.", op_function());
 	}
  }
}

